@@ -6,6 +6,7 @@ use std::path::PathBuf;
 
 use anyhow::{anyhow, Error, Result};
 use regex::Regex;
+use strip_bom::StripBom;
 use xmltree::Element;
 use zip::ZipArchive;
 
@@ -343,7 +344,7 @@ fn parse_nav_points(nav_points_element: &Element, level: usize, nav_points: &mut
 }
 
 fn parse_ncx(text: &str) -> Result<Vec<NavPoint>> {
-	let ncx = xmltree::Element::parse(text.as_bytes())
+	let ncx = xmltree::Element::parse(text.strip_bom().as_bytes())
 		.map_err(|_e| anyhow!("Invalid XML"))?;
 	let nav_map = ncx
 		.get_child("navMap")
@@ -400,7 +401,7 @@ pub fn parse_spine(spine: &Element) -> Option<Spine> {
 }
 
 fn parse_content_opf(text: &str) -> Option<ContentOPF> {
-	let package = xmltree::Element::parse(text.as_bytes()).ok()?;
+	let package = xmltree::Element::parse(text.strip_bom().as_bytes()).ok()?;
 	let metadata = package.get_child("metadata")?;
 	let manifest = package.get_child("manifest")?;
 	let spine = package.get_child("spine")?;
@@ -453,17 +454,11 @@ fn toc_index_for_chapter<'a>(chapter_index: usize, chapter_path: &str, id_map: &
 				}
 			}
 		}
-		if file_matched.is_some() {
-			break;
+		if let Some(the_last_index_found) = file_matched {
+			return the_last_index_found;
 		}
 	}
-	file_matched.unwrap_or_else(|| {
-		if chapter_index == 0 {
-			0
-		} else {
-			toc.len() - 1
-		}
-	})
+	0
 }
 
 fn toc_title(nav_point: &NavPoint) -> &String {
