@@ -2,11 +2,12 @@ use anyhow::Result;
 
 use crate::book::{Book, Line, Loader};
 use crate::html_convertor::{html_content, HtmlContent};
+use crate::view::TraceInfo;
 
 pub(crate) struct HtmlLoader {}
 
 pub(crate) struct HtmlBook {
-	content: HtmlContent
+	content: HtmlContent,
 }
 
 impl HtmlLoader {
@@ -31,4 +32,15 @@ impl Book for HtmlBook {
 	fn lines(&self) -> &Vec<Line> {
 		&self.content.lines
 	}
+
+	fn link_position(&mut self, line: usize, link_index: usize) -> Option<TraceInfo> {
+		let text = &self.content.lines.get(line)?;
+		let link = text.link_at(link_index)?;
+		let link_target = link.target.as_str();
+		let mut split = link_target.split('#');
+		split.next()?;
+		let anchor = split.next()?;
+		let position = self.content.id_map.get(anchor)?;
+		Some(TraceInfo { chapter: 0, line: position.line, position: position.position })
+	}
 }
\ No newline at end of file
